<!-- This file is generated. DO NOT EDIT -->

# Ruff

Ruff is an extremely fast Python linter and code formatter.

See the [documentation](https://docs.astral.sh/ruff/) or
[repository](https://github.com/astral-sh/ruff) for more information.

This crate is the entry point to the Ruff command-line interface. The Rust API exposed here is not
considered public interface.

This is version 0.16.3. The source can be found [here](https://github.com/astral-sh/ruff/blob/0.16.3/crates/ruff).

The following Ruff workspace members are also available:

- [ruff_annotate_snippets](https://crates.io/crates/ruff_annotate_snippets)
- [ruff_cache](https://crates.io/crates/ruff_cache)
- [ruff_db](https://crates.io/crates/ruff_db)
- [ruff_diagnostics](https://crates.io/crates/ruff_diagnostics)
- [ruff_formatter](https://crates.io/crates/ruff_formatter)
- [ruff_graph](https://crates.io/crates/ruff_graph)
- [ruff_index](https://crates.io/crates/ruff_index)
- [ruff_linter](https://crates.io/crates/ruff_linter)
- [ruff_macros](https://crates.io/crates/ruff_macros)
- [ruff_markdown](https://crates.io/crates/ruff_markdown)
- [ruff_memory_usage](https://crates.io/crates/ruff_memory_usage)
- [ruff_notebook](https://crates.io/crates/ruff_notebook)
- [ruff_options_metadata](https://crates.io/crates/ruff_options_metadata)
- [ruff_python_ast](https://crates.io/crates/ruff_python_ast)
- [ruff_python_codegen](https://crates.io/crates/ruff_python_codegen)
- [ruff_python_formatter](https://crates.io/crates/ruff_python_formatter)
- [ruff_python_importer](https://crates.io/crates/ruff_python_importer)
- [ruff_python_index](https://crates.io/crates/ruff_python_index)
- [ruff_python_literal](https://crates.io/crates/ruff_python_literal)
- [ruff_python_parser](https://crates.io/crates/ruff_python_parser)
- [ruff_python_semantic](https://crates.io/crates/ruff_python_semantic)
- [ruff_python_stdlib](https://crates.io/crates/ruff_python_stdlib)
- [ruff_python_trivia](https://crates.io/crates/ruff_python_trivia)
- [ruff_ranged_value](https://crates.io/crates/ruff_ranged_value)
- [ruff_server](https://crates.io/crates/ruff_server)
- [ruff_source_file](https://crates.io/crates/ruff_source_file)
- [ruff_text_size](https://crates.io/crates/ruff_text_size)
- [ruff_wasm](https://crates.io/crates/ruff_wasm)
- [ruff_workspace](https://crates.io/crates/ruff_workspace)
- [ty_combine](https://crates.io/crates/ty_combine)
- [ty_module_resolver](https://crates.io/crates/ty_module_resolver)
- [ty_python_core](https://crates.io/crates/ty_python_core)
- [ty_python_semantic](https://crates.io/crates/ty_python_semantic)
- [ty_site_packages](https://crates.io/crates/ty_site_packages)
- [ty_static](https://crates.io/crates/ty_static)
- [ty_vendored](https://crates.io/crates/ty_vendored)

Ruff's workspace members are considered internal and will have frequent breaking changes.

See Ruff's [crate versioning policy](https://docs.astral.sh/ruff/versioning/#crate-versioning) for
details on versioning.
